==> protobuf_3.0.0.orig.tar.gz: protobuf-3.0.0/csharp/src/Google.Protobuf/Compatibility/PropertyInfoExtensions.cs <==
﻿#region Copyright notice and license
// Protocol Buffers - Google's data interchange format
// Copyright 2015 Google Inc.  All rights reserved.
// https://developers.google.com/protocol-buffers/
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System.Reflection;

namespace Google.Protobuf.Compatibility
{
    /// <summary>
    /// Extension methods for <see cref="PropertyInfo"/>, effectively providing
    /// the familiar members from previous desktop framework versions while
    /// targeting the newer releases, .NET Core etc.
    /// </summary>
    internal static class PropertyInfoExtensions
    {
        /// <summary>
        /// Returns the public getter of a property, or null if there is no such getter
        /// (either because it's read-only, or the getter isn't public).
        /// </summary>
        internal static MethodInfo GetGetMethod(this PropertyInfo target)
        {
#if DOTNET35
            var method = target.GetGetMethod();
#else
            var method = target.GetMethod;
#endif
            return method != null && method.IsPublic ? method : null;
        }

        /// <summary>
        /// Returns the public setter of a property, or null if there is no such setter
        /// (either because it's write-only, or the setter isn't public).
        /// </summary>
        internal static MethodInfo GetSetMethod(this PropertyInfo target)
        {
#if DOTNET35
            var method = target.GetSetMethod();
#else
            var method = target.SetMethod;
#endif
            return method != null && method.IsPublic ? method : null;
        }
    }
}

==> protobuf-32.1.tar.gz: protobuf-32.1/csharp/src/Google.Protobuf/Compatibility/PropertyInfoExtensions.cs <==
﻿#region Copyright notice and license
// Protocol Buffers - Google's data interchange format
// Copyright 2015 Google Inc.  All rights reserved.
//
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file or at
// https://developers.google.com/open-source/licenses/bsd
#endregion

using System.Reflection;

namespace Google.Protobuf.Compatibility
{
    /// <summary>
    /// Extension methods for <see cref="PropertyInfo"/>, effectively providing
    /// the familiar members from previous desktop framework versions while
    /// targeting the newer releases, .NET Core etc.
    /// </summary>
    internal static class PropertyInfoExtensions
    {
        /// <summary>
        /// Returns the public getter of a property, or null if there is no such getter
        /// (either because it's read-only, or the getter isn't public).
        /// </summary>
        internal static MethodInfo GetGetMethod(this PropertyInfo target)
        {
            var method = target.GetMethod;
            return method != null && method.IsPublic ? method : null;
        }

        /// <summary>
        /// Returns the public setter of a property, or null if there is no such setter
        /// (either because it's write-only, or the setter isn't public).
        /// </summary>
        internal static MethodInfo GetSetMethod(this PropertyInfo target)
        {
            var method = target.SetMethod;
            return method != null && method.IsPublic ? method : null;
        }
    }
}
